/**
* A module for fetching & displaying the videosprechstunde (arzt-direkt) time-schedule
*/

const videosprechstunde = (() => {

  /* Constants & Variables */

  const FETCH_BASE_URL = 'https://arzt-direkt.com'

  const TABLE_SELECTOR = '[data-js="videosprechstunde-table"]'
  const BADGE_SELECTOR = '[data-js="videosprechstunde-badge"]'
  
  let tableEls = []
  let badgeEls = []

  let plannedAvailability = {}
  let onlineDoctors = {}


  /* Private Functions */

  function fetchPlannedAvailability() {
    return new Promise((resolve, reject) => {
      try {
        plannedAvailability = {}
        const url = `${FETCH_BASE_URL}/api/landing/hautpraxis-jena/planned-availability`
        fetch(url, { method: 'GET' })
          .then((response) => response.json())
          .then((response) => {
            plannedAvailability = response['plannedAvailability'] || {}
            resolve()
          })
  
      } catch (error) {
        console.error("Error while fetching planned-availability:", error)
        reject(error)
      }
    })
  }


  function fetchOnlineDoctors() {
    return new Promise((resolve, reject) => {
      try {
        onlineDoctors = {}
        const url = `${FETCH_BASE_URL}/api/landing/hautpraxis-jena/online-doctors`
        fetch(url, { method: 'GET' })
          .then((response) => response.json())
          .then((response) => {
            onlineDoctors = response['onlineDoctors'] || {}
            resolve()
          })

      } catch (error) {
        console.error("Error while fetching online-doctors:", error)
        reject(error)
      }
    })
  }


  function updateTables() {
    if (!plannedAvailability || !plannedAvailability['sum']) return
    if (!tableEls || !tableEls.length) return

    // Iterate over each weekday
    const sum = plannedAvailability['sum']
    for (const key of Object.keys(sum)) {
      const elements = document.querySelectorAll(`${TABLE_SELECTOR} [data-js="${key}"]`)
      if (!elements) continue

      for (const element of Array.from(elements)) {
        if (sum[key]) {
          element.innerHTML = sum[key] + " Uhr"
          element.classList.remove('empty')
        } else {
          element.innerHTML = ""
          element.classList.add('empty')
        }
      }
    }  
  }

  function updateBadges() {
    if (!onlineDoctors) return
    if (!badgeEls || !badgeEls.length) return

    const sum = onlineDoctors['sum']
    for (const badgeEl of badgeEls) {
      if (!!sum) {
        const arztString = (sum > 1) ? 'Ärzte online' : 'Arzt online'
        badgeEl.innerHTML = `${sum} ${arztString}`
        badgeEl.classList.add('c-section__header__badge--isGreen')
      } else {
        badgeEl.innerHTML = 'Jetzt neu'
        badgeEl.classList.remove('c-section__header__badge--isGreen')
      }
    }
  }


  /* Public Functions */

  return {

    'init': () => {
      // Fetch planned-availability and fill table
      tableEls = document.querySelectorAll(TABLE_SELECTOR)
      if (tableEls) {
        tableEls = Array.from(tableEls)
        fetchPlannedAvailability().then(() => { updateTables() })
      }

      // Fetch online-doctors and update badge
      badgeEls = document.querySelectorAll(BADGE_SELECTOR)
      if (badgeEls) {
        badgeEls = Array.from(badgeEls)
        fetchOnlineDoctors().then(() => { updateBadges() })
      }
    },

  }

})()



/**
* Setup Anchors with nav-height as offset if 'scroll-behavior' isn't available.
*/

document.addEventListener("DOMContentLoaded", function(event) {
  videosprechstunde.init('[data-js="videosprechstunde-table"]')
});
